@@ -546,7 +546,6 @@ For example, to fork the program into four concurrent processes.
 		$pm->start and next;
 		### in child
 		$Data->splice_data($i, 4);
-		$db = $Data->open_database; # a clone-safe new db object
 		# do something with this portion
 		$Data->save('filename' => "file#$i");
 		$pm->finish;
@@ -557,16 +556,9 @@ There is no convenient method for merging the modified contents of the
 table from each child process back into the original Data table, as 
 each child is essentially isolated from the parent. The Parallel::ForkManager 
 documentation recommends going through a disk file intermediate. See the 
-accompanying BioToolBox script F<join_data_file.pl> for concatenating Data 
+accompanying BioToolBox script join_data_file.pl for concatenating Data 
 table files together.
 
-Remember that if you fork your script into child processes, any database 
-connections must be re-opened; they are typically not clone safe. If you 
-have an existing database connection by using the open_database() method, 
-it should be automatically re-opened for you when you use the splice_data() 
-method, but you will need to call open_database() again in the child 
-process to obtain the new database object.
-
 =item convert_gff(%options)
 
 This method will irreversibly convert the Data table into a GFF format.
@@ -866,13 +858,7 @@ sub verify {
 
 sub splice_data {
 	my $self = shift;
-	splice_data_structure($self, @_);
-	if ($self->{db} and exists $self->{db_connection}) {
-		# re-open a new un-cached database connection
-		my $db = open_db_connection($self->{db}, 1);
-		$self->{db_connection} = $db if $db;
-	}
-	return 1;
+	return splice_data_structure($self, @_);
 }
 
 sub convert_gff {
@@ -908,8 +894,7 @@ sub database {
 	if (@_) {
 		$self->{db} = shift;
 		if (exists $self->{db_connection}) {
-			my $db = open_db_connection($self->{db});
-			$self->{db_connection} = $db if $db;
+			$self->{db_connection} = open_db_connection($self->{db});
 		}
 	}
 	return $self->{db};
