@@ -6,7 +6,7 @@ use strict;
 use Carp;
 use Statistics::Lite qw(mean);
 use Bio::DB::BigBed;
-our $VERSION = '1.14.1';
+our $VERSION = '1.14';
 
 
 # Exported names
@@ -18,6 +18,12 @@ our @EXPORT = qw(
 	sum_total_bigbed_features
 );
 
+# Hashes of opened file objects
+our %OPENED_BEDFILES; # opened bigbed file objects
+	# in empirical testing, this doesn't really seem to speed things up
+	# like I thought it would
+	# oh well, keep it anyway????
+
 # Hash of Bigfile chromosomes
 our %BIGBED_CHROMOS;
 	# sometimes user may request a chromosome that's not in the bigfile
@@ -222,22 +228,35 @@ sub collect_bigbed_position_scores {
 ### Open a bigBed database connection
 sub open_bigbed_db {
 	
-	# check path
 	my $bedfile = shift;
-	my $path = $bedfile;
-	$path =~ s/^file://; # clean up file prefix if present
+	my $forget  = shift;
 	
-	# open
-	my $bb;
-	eval {
-		$bb = Bio::DB::BigBed->new($path);
-	};
-	return unless $bb;
+	# check whether the file has been opened or not
+	if (exists $OPENED_BEDFILES{$bedfile} ) {
+		# this file is already opened, use it
+		return $OPENED_BEDFILES{$bedfile};
+	}
 	
-	# collect the chromosomes for this bigBed file
-	%{ $BIGBED_CHROMOS{$bedfile} } = map { $_ => 1 } $bb->seq_ids;
-	
-	return $bb;
+	else {
+		# this file has not been opened yet, open it
+		my $path = $bedfile;
+		$path =~ s/^file://; # clean up file prefix if present
+		my $bb;
+		eval {
+			$bb = Bio::DB::BigBed->new($path);
+		};
+		return unless $bb;
+		
+		unless ($forget) {
+			# store the opened object for later use
+			$OPENED_BEDFILES{$bedfile} = $bb;
+		
+			# collect the chromosomes for this bigBed file
+			%{ $BIGBED_CHROMOS{$bedfile} } = map { $_ => 1 } $bb->seq_ids;
+		}
+		
+		return $bb;
+	}
 }
 
 
@@ -263,7 +282,7 @@ sub sum_total_bigbed_features {
 	else {
 		# we have a name of a bigbed file
 		# open it but do not remember it
-		$bb = open_bigbed_db($bb_file);
+		$bb = open_bigbed_db($bb_file, 1);
 		return unless ($bb);
 	}
 	
@@ -298,6 +317,10 @@ feature is collected.
 For loading bigbed files into a Bio::DB database, see the biotoolbox perl 
 script 'big_filegff3.pl'.
 
+To speed up the program and avoid repetitive opening and 
+closing of the files, the opened bigbed file object is stored in a global 
+hash in case it is needed again.
+
 =head1 USAGE
 
 The module requires Lincoln Stein's Bio::DB::BigBed to be installed. 
