@@ -38,7 +38,7 @@ use constant (DATASET_HASH_LIMIT => 3000);
 		# region, and a hash returned with potentially a score for each basepair. 
 		# This may become unwieldy for very large regions, which may be better 
 		# served by separate database queries for each window.
-my $VERSION = '1.14.1';
+my $VERSION = '1.14';
 
 print "\n This script will collect binned values across genes to create an average gene\n\n";
 
@@ -392,10 +392,9 @@ sub parallel_execution {
 		splice_data_structure($main_data_ref, $i, $cpu);
 		
 		# re-open database objects to make them clone safe
-		# pass second true to avoid cached database objects
-		$mdb = open_db_connection($main_database, 1);
+		$mdb = open_db_connection($main_database);
 		if ($data_database) {
-			$ddb = open_db_connection($data_database, 1);
+			$ddb = open_db_connection($data_database);
 		}
 		else {
 			$ddb = $mdb;
