@@ -41,7 +41,7 @@ eval {
 	require Parallel::ForkManager;
 	$parallel = 1;
 };
-my $VERSION = '1.14.1';
+my $VERSION = '1.14';
 
 
 print "\n A program to collect data for a list of features\n\n";
@@ -638,10 +638,9 @@ sub parallel_execution {
 		splice_data_structure($main_data_ref, $i, $cpu);
 		
 		# re-open database objects to make them clone safe
-		# pass second true to avoid cached database objects
-		$mdb = open_db_connection($main_database, 1);
+		$mdb = open_db_connection($main_database);
 		if ($data_database) {
-			$ddb = open_db_connection($data_database, 1);
+			$ddb = open_db_connection($data_database);
 		}
 		else {
 			$ddb = $mdb;
